@@ -77,15 +77,13 @@ pub(crate) fn get_subfields_for_layout(
     resolved_type_of_parent: TypeId,
 ) -> Vec<(TypeId, Span, Ident)> {
     // TODO(static span): str should be ident below
-    let span = sway_types::span::Span {
-        span: pest::Span::new(
-            "TODO(static span): use Idents instead of Strings".into(),
-            0,
-            0,
-        )
-        .unwrap(),
-        path: None,
-    };
+    let span = sway_types::span::Span::new(
+        "TODO(static span): use Idents instead of Strings".into(),
+        0,
+        0,
+        None,
+    )
+    .unwrap();
 
     match look_up_type_id(resolved_type_of_parent) {
         TypeInfo::Struct { fields, .. } => fields
@@ -145,10 +143,13 @@ pub(crate) fn convert_subfield_to_asm(
             "Accessing a subfield that is not on the struct would be caught during type checking",
         );
 
-    let span = sway_types::span::Span {
-        span: pest::Span::new("TODO(static span): use span_for_this_field".into(), 0, 0).unwrap(),
-        path: None,
-    };
+    let span = sway_types::span::Span::new(
+        "TODO(static span): use span_for_this_field".into(),
+        0,
+        0,
+        None,
+    )
+    .unwrap();
     // step 3
     // if this is a copy type (primitives that fit in a word), copy it into the register.
     // Otherwise, load the pointer to the field into the register
