@@ -17,3 +17,6 @@ pub const CONTRACT_CALL_COINS_PARAMETER_DEFAULT_VALUE: u64 = 0;
 
 pub const CONTRACT_CALL_ASSET_ID_PARAMETER_NAME: &str = "asset_id";
 pub const CONTRACT_CALL_ASSET_ID_PARAMETER_DEFAULT_VALUE: [u8; 32] = [0; 32];
+
+/// The default entry point for scripts and predicates.
+pub const DEFAULT_ENTRY_POINT_FN_NAME: &str = "main";
