@@ -10,11 +10,11 @@ use pest::iterators::Pair;
 #[derive(Debug, Clone)]
 pub struct AbiDeclaration {
     /// The name of the abi trait (also known as a "contract trait")
-    pub(crate) name: Ident,
+    pub name: Ident,
     /// The methods a contract is required to implement in order opt in to this interface
-    pub(crate) interface_surface: Vec<TraitFn>,
+    pub interface_surface: Vec<TraitFn>,
     /// The methods provided to a contract "for free" upon opting in to this interface
-    pub(crate) methods: Vec<FunctionDeclaration>,
+    pub methods: Vec<FunctionDeclaration>,
     pub(crate) span: Span,
 }
 
