@@ -19,14 +19,14 @@ use pest::iterators::Pair;
 pub struct EnumDeclaration {
     pub name: Ident,
     pub(crate) type_parameters: Vec<TypeParameter>,
-    pub(crate) variants: Vec<EnumVariant>,
+    pub variants: Vec<EnumVariant>,
     pub(crate) span: Span,
     pub visibility: Visibility,
 }
 
 #[derive(Debug, Clone)]
-pub(crate) struct EnumVariant {
-    pub(crate) name: Ident,
+pub struct EnumVariant {
+    pub name: Ident,
     pub(crate) r#type: TypeInfo,
     pub(crate) tag: usize,
     pub(crate) span: Span,
