@@ -17,7 +17,7 @@ pub enum MethodName {
 
 impl MethodName {
     /// To be used for error messages and debug strings
-    pub(crate) fn easy_name(&self) -> Ident {
+    pub fn easy_name(&self) -> Ident {
         match self {
             MethodName::FromType { call_path, .. } => call_path.suffix.clone(),
             MethodName::FromModule { method_name, .. } => method_name.clone(),
