@@ -7,7 +7,7 @@ use crate::{
             TypedExpressionVariant, TypedReturnStatement, TypedVariableDeclaration,
             VariableMutability,
         },
-        create_new_scope, NamespaceWrapper, TypeCheckArguments,
+        create_new_scope, NamespaceWrapper, TypeCheckArguments, TypedAstNode, TypedAstNodeContent,
     },
     type_engine::*,
     Ident, TypeParameter,
@@ -37,6 +37,18 @@ pub struct TypedFunctionDeclaration {
     pub(crate) purity: Purity,
 }
 
+impl From<&TypedFunctionDeclaration> for TypedAstNode {
+    fn from(o: &TypedFunctionDeclaration) -> Self {
+        let span = o.span.clone();
+        TypedAstNode {
+            content: TypedAstNodeContent::Declaration(TypedDeclaration::FunctionDeclaration(
+                o.clone(),
+            )),
+            span,
+        }
+    }
+}
+
 // NOTE: Hash and PartialEq must uphold the invariant:
 // k1 == k2 -> hash(k1) == hash(k2)
 // https://doc.rust-lang.org/std/collections/struct.HashMap.html
