@@ -12,8 +12,11 @@ use crate::{
 };
 use generational_arena::{Arena, Index};
 use lazy_static::lazy_static;
-use std::{collections::VecDeque, sync::RwLock};
-use sway_types::{join_spans, Ident, Span};
+use std::{
+    collections::VecDeque,
+    sync::{Arc, RwLock},
+};
+use sway_types::{Ident, Span};
 pub type NamespaceRef = Index;
 
 pub trait NamespaceWrapper {
@@ -86,6 +89,7 @@ pub trait NamespaceWrapper {
     /// and `function` is the suffix
     fn get_call_path(&self, symbol: &CallPath) -> CompileResult<TypedDeclaration>;
     fn get_symbol(&self, symbol: &Ident) -> CompileResult<TypedDeclaration>;
+    fn get_canonical_path(&self, symbol: &Ident) -> Vec<Ident>;
     fn find_enum(&self, enum_name: &Ident) -> Option<TypedEnumDeclaration>;
     /// given a declaration that may refer to a variable which contains a struct,
     /// find that struct's fields and name for use in determining if a subfield expression is valid
@@ -142,10 +146,7 @@ impl NamespaceWrapper for NamespaceRef {
             ok(fields, vec![], vec![])
         } else {
             let msg = "unknown source location";
-            let span = Span {
-                span: pest::Span::new(std::sync::Arc::from(msg), 0, msg.len()).unwrap(),
-                path: None,
-            };
+            let span = Span::new(Arc::from(msg), 0, msg.len(), None).unwrap();
             err(vec![], vec![CompileError::NoDeclaredStorage { span }])
         }
     }
@@ -281,6 +282,13 @@ impl NamespaceWrapper for NamespaceRef {
         }
     }
 
+    fn get_canonical_path(&self, symbol: &Ident) -> Vec<Ident> {
+        read_module(
+            |m| m.use_synonyms.get(symbol).unwrap_or(&vec![]).clone(),
+            *self,
+        )
+    }
+
     fn get_symbol(&self, symbol: &Ident) -> CompileResult<TypedDeclaration> {
         let (path, true_symbol) = read_module(
             |m| {
@@ -485,7 +493,7 @@ impl NamespaceWrapper for NamespaceRef {
             None => {
                 errors.push(CompileError::ModuleNotFound {
                     span: path.iter().fold(path[0].span().clone(), |acc, this_one| {
-                        join_spans(acc, this_one.span().clone())
+                        Span::join(acc, this_one.span().clone())
                     }),
                     name: path
                         .iter()
@@ -507,7 +515,7 @@ impl NamespaceWrapper for NamespaceRef {
                 _ => {
                     errors.push(CompileError::ModuleNotFound {
                         span: path.iter().fold(path[0].span().clone(), |acc, this_one| {
-                            join_spans(acc, this_one.span().clone())
+                            Span::join(acc, this_one.span().clone())
                         }),
                         name: path
                             .iter()
